AssociatedCiphertext

Struct AssociatedCiphertext 

pub struct AssociatedCiphertext<'pk, C: Associable<PK>, PK: EncryptionKey<Ciphertext = C>> {
    pub ciphertext: C,
    pub public_key: &'pk PK,
}
An AssociatedCiphertext associates a ciphertext with a reference to the corresponding public key to make homomorphic operations and decrypting more ergonomic.

Fields

ciphertext: C

A potentially homomorphic ciphertext

public_key: &'pk PK

The related public key

Implementations

Source

impl<'pk, C: Associable<PK>, PK: EncryptionKey<Ciphertext = C> + HomomorphicMultiplication> AssociatedCiphertext<'pk, C, PK>

pub fn pow(&self, rhs: &PK::Input) -> AssociatedCiphertext<'pk, C, PK>

Applies some operation on this ciphertext so that the decrypted value reflects some exponentiation with input